@@ -4,6 +4,10 @@ __all__ = [
     "Papers",
     "Repository",
     "Repositories",
+    "PaperRepo",
+    "PaperRepos",
+    "Author",
+    "Authors",
     "Conference",
     "Conferences",
     "Proceeding",
@@ -43,6 +47,8 @@ __all__ = [
 from paperswithcode.models.page import Page
 from paperswithcode.models.paper import Paper, Papers
 from paperswithcode.models.repository import Repository, Repositories
+from paperswithcode.models.paper_repo import PaperRepo, PaperRepos
+from paperswithcode.models.author import Author, Authors
 from paperswithcode.models.conference import (
     Conference,
     Conferences,
